=======
SyllaPy
=======


.. image:: https://img.shields.io/pypi/v/syllapy.svg
        :target: https://pypi.python.org/pypi/syllapy

.. image:: https://img.shields.io/travis/mholtzscher/syllapy.svg
        :target: https://travis-ci.org/mholtzscher/syllapy

.. image:: https://readthedocs.org/projects/syllapy/badge/?version=latest
        :target: https://syllapy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/mholtzscher/syllapy/shield.svg
     :target: https://pyup.io/repos/github/mholtzscher/syllapy/
     :alt: Updates



Calculate syllable counts for English words.


* Free software: MIT license
* Documentation: https://syllapy.readthedocs.io.


************
Installation
************
.. code-block:: python

    pip install syllapy

*****
Usage
*****

.. code-block:: python

    import syllapy
    count = syllapy.count('additional')

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
